Welcome to ladybug-vtk's documentation!
===================================

.. image:: https://raw.githubusercontent.com/devngc/honeybee-vtk/master/images/vtk.png

Ladybug extension for translating ladybug-geometry objects to VTK PolyData.

Installation
============

``pip install -U ladybug-vtk``

.. toctree::
   :maxdepth: 4
   :caption: Contents:

.. include:: modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
